@@ -12,7 +12,6 @@ import torch
 import torch.distributed as dist
 import torchvision
 from codetiming import Timer
-from torch.utils.tensorboard import SummaryWriter
 from torchvision import transforms
 from tqdm import tqdm
 
@@ -20,6 +19,7 @@ import datasetinsights.constants as const
 from datasetinsights.datasets import Dataset
 from datasetinsights.evaluation_metrics.base import EvaluationMetric
 from datasetinsights.io.bbox import BBox2D
+from datasetinsights.io.summarywriter import get_summary_writer
 from datasetinsights.io.transforms import Compose
 from datasetinsights.torch_distributed import get_world_size, is_master
 
@@ -79,7 +79,9 @@ class FasterRCNN(Estimator):
         self._init_distributed_mode()
         self.no_cuda = no_cuda
         self._init_device()
-        self.writer = SummaryWriter(logdir)
+
+        summary_writer = get_summary_writer()
+        self.writer = summary_writer(logdir)
 
         self.kfp_writer = kfp_writer
         checkpointer.distributed = self.distributed
@@ -306,6 +308,7 @@ class FasterRCNN(Estimator):
                     f"(total training examples: {examples_seen}) is "
                     f"{intermediate_loss}"
                 )
+
                 self.writer.add_scalar(
                     "training/intermediate_loss",
                     intermediate_loss,
@@ -316,12 +319,8 @@ class FasterRCNN(Estimator):
                 optimizer.step()
                 lr_scheduler.step()
                 optimizer.zero_grad()
+
         self.writer.add_scalar("training/loss", loss_metric.compute(), epoch)
-        self.writer.add_scalar(
-            "training/running_loss",
-            loss_metric.compute(),
-            loss_metric.num_examples,
-        )
         self.writer.add_scalar(
             "training/lr", optimizer.param_groups[0]["lr"], epoch
         )
@@ -424,6 +423,7 @@ class FasterRCNN(Estimator):
         self.log_metric_val(label_mappings, epoch)
         val_loss = loss_metric.compute()
         logger.info(f"validation loss is {val_loss}")
+
         self.writer.add_scalar("val/loss", val_loss, epoch)
 
         torch.set_num_threads(n_threads)
@@ -452,6 +452,7 @@ class FasterRCNN(Estimator):
                     label_mappings.get(id, str(id)): value
                     for id, value in result.items()
                 }
+
                 self.writer.add_scalars(
                     f"val/{metric_name}-per-class", label_results, epoch
                 )
