@@ -14,6 +14,9 @@ from datasetinsights.evaluation_metrics.confusion_matrix import (
 from datasetinsights.stats.visualization.bbox2d_plot import (
     add_single_bbox_on_image,
 )
+from datasetinsights.stats.visualization.bbox3d_plot import (
+    add_single_bbox3d_on_image,
+)
 
 logger = logging.getLogger(__name__)
 COLORS = list(ImageColor.colormap.values())
@@ -95,6 +98,8 @@ def _process_label(bbox, label_mappings=None):
     """
     if label_mappings is not None:
         label = label_mappings[bbox.label]
+    else:
+        label = bbox.label
     if bbox.score != 1.0:
         return f"{label}: {bbox.score * 100: .2f}%"
     else:
@@ -128,6 +133,34 @@ def match_boxes(pred_bboxes, gt_bboxes):
     return colors
 
 
+def plot_bboxes3d(image, bboxes, projection, colors=None):
+    """ Plot an image with 3D bounding boxes
+
+    Currently this method should only be used for ground truth images, and
+    doesn't support predictions. If a list of colors is not provided as an
+    argument to this routine, the default color of green will be used.
+
+    Args:
+        image (PIL Image): a PIL image.
+        bboxes (list): a list of BBox3D objects
+        projection: The perspective projection of the camera which
+        captured the ground truth.
+        colors (list): a color list for boxes. Defaults to none. If
+        colors = None, it will default to coloring all boxes green.
+
+    Returns:
+        PIL image: a PIL image with bounding boxes drawn on it.
+    """
+    np_image = np.array(image)
+    img_height, img_width, _ = np_image.shape
+
+    for i, box in enumerate(bboxes):
+        color = colors[i] if colors else None
+        add_single_bbox3d_on_image(np_image, box, projection, color)
+
+    return Image.fromarray(np_image)
+
+
 def plot_bboxes(image, bboxes, label_mappings=None, colors=None):
     """ Plot an image with bounding boxes.
 
